@@ -37,16 +37,14 @@ class LightSensorThing(Thing):
                      }))
 
     def on_measured(self, brightness: int):
-        print("on_measured " + str(brightness))
         self.ioloop.add_callback(self.__update_brightness, brightness)
 
     def __update_brightness(self, brightness: int):
-        print("__update_brightness " + str(brightness))
         self.bright.notify_of_external_update(brightness)
 
 
-def run_server(port: int, description: str = "", measure_period: int = 7):
-    light_sensor = LightSensorThing(description, LightSensor(measure_period))
+def run_server(port: int, description: str = ""):
+    light_sensor = LightSensorThing(description, LightSensor())
     server = WebThingServer(SingleThing(light_sensor), port=port, disable_host_validation=True)
     try:
         logging.info('starting the server')
